[−][src]Struct hawk::RequestBuilder
Methods
impl<'a> RequestBuilder<'a>[src]
pub fn new(method: &'a str, host: &'a str, port: u16, path: &'a str) -> Self[src]
Create a new request with the given method, host, port, and path.
pub fn from_url(method: &'a str, url: &'a Url) -> Result<Self>[src]
Create a new request with the host, port, and path determined from the URL.
pub fn method(self, method: &'a str) -> Self[src]
Set the request method. This should be a capitalized string.
pub fn path(self, path: &'a str) -> Self[src]
Set the URL path for the request.
pub fn host(self, host: &'a str) -> Self[src]
Set the URL hostname for the request
pub fn port(self, port: u16) -> Self[src]
Set the URL port for the request
pub fn url(self, url: &'a Url) -> Result<Self>[src]
Set the hostname, port, and path for the request, from a string URL.
pub fn hash<H: Into<Option<&'a [u8]>>>(self, hash: H) -> Self[src]
Set the content hash for the request
pub fn ext<S: Into<Option<&'a str>>>(self, ext: S) -> Self[src]
Set the ext Hawk property for the request
pub fn app<S: Into<Option<&'a str>>>(self, app: S) -> Self[src]
Set the app Hawk property for the request
pub fn dlg<S: Into<Option<&'a str>>>(self, dlg: S) -> Self[src]
Set the dlg Hawk property for the request
pub fn request(self) -> Request<'a>[src]
Get the request from this builder